@@ -25,7 +25,7 @@ from dask import delayed
 from dask import compute
 
 #imports for numba to accelerate code and compilation
-from numba import jit
+import numba
 from numba.experimental import jitclass #used for the VarDelay class
 from numba import float32, float64, int16, int32 #used for the VarDelay class
 from numba import vectorize
@@ -110,6 +110,25 @@ def convertBinaryString(string):
 		temp += a
 	return temp
 
+@numba.jit("uint32(uint16[:])")
+def Fletcher32(data):
+	"""
+	Returns the checksum of a particular array of values as determined by the Fletcher32 algorithm.
+	Source: https://en.wikipedia.org/wiki/Fletcher%27s_checksum
+	This implementation was verified to match the check values in the table. 
+	No overflow protection is built in to the addition as in the Nab dataset cannot overflow when using 64-bit containers for the addition.
+	Returned value is a 32-bit checksum
+		Python may cast this to a 64-bit number but it's really 32-bit
+	"""
+	sum1 = 0
+	sum2 = 0
+	for d in data:
+		sum1 = sum1+d
+		sum2 = sum2+sum1
+	sum1 = sum1%65535
+	sum2 = sum2%65535
+	return (sum2<<16)|sum1
+
 
 #waveform preparation functions
 @vectorize(['int16(uint16)', 'int16(int16)'])
@@ -165,7 +184,7 @@ def wavePrep(waveform, forcePrep = False):
 Compression Functions
 -----------------------------------------------------------------------------
 '''
-@jit
+@numba.jit
 def encodeWaveform(waveform, filt):
 	'''
 	This function uses a passed filter to encode the waveform. This is a general form of 
@@ -194,7 +213,7 @@ def encodeWaveform(waveform, filt):
 			encoded[i] = out
 	return encoded
 
-@jit
+@numba.jit
 def decodeWaveform(encoded, filt):
 	output = np.zeros_like(encoded)
 	if np.array_equal(filt.astype(np.int16), np.array([1, -1], dtype=np.int16)):
@@ -218,15 +237,15 @@ def decodeWaveform(encoded, filt):
 		output[i] = temp
 	return output
 
-@jit(inline='always')
+@numba.jit(inline='always')
 def getBit(cont, bitnum, end):
 	return (cont >> (end - bitnum))&1
 
-@jit(inline='always')
+@numba.jit(inline='always')
 def getBit64(cont, bitnum):
 	return ((cont>>(63-bitnum))&1)
 
-@jit
+@numba.jit
 def __determinePowerOf2(M):
 	if M <= 0: #invalid
 		return -1
@@ -244,7 +263,7 @@ def __determinePowerOf2(M):
 				i += 1
 		return -1
 
-@jit
+@numba.jit
 def compressWithRiceCoding(waveIn, M=8):
 	'''
 	This function encodes the given array using Rice coding to compress the data. 
@@ -312,7 +331,7 @@ def compressWithRiceCoding(waveIn, M=8):
 	out = np.array(out, dtype=np.uint32)
 	return out
 
-@jit
+@numba.jit
 def decompressWithRiceCoding(compressedIn, length, M=8):
 	'''
 	This function decodes the given array using Rice coding to decompress the data. 
@@ -477,7 +496,7 @@ Define some classes to be used in the DAQ Filter Emulation.
 These are used to replicate the delay functions in the DAQ.
 '''
 spec = [('data', int32[:])]
-@jitclass(spec)
+@numba.jitclass(spec)
 class VarDelay:
 	def __init__(self,size):
 		self.data = np.zeros(size, dtype=int32)
@@ -488,7 +507,7 @@ class VarDelay:
 		return first_out
 
 spec = [('data', float32[:])]
-@jitclass(spec)
+@numba.jitclass(spec)
 class VarDelayFloat:
 	def __init__(self,size):
 		self.data = np.zeros(size, dtype=float32)
@@ -498,7 +517,7 @@ class VarDelayFloat:
 		self.data[0] = value
 		return first_out
 
-@jit
+@numba.jit
 def daqFilterEmulator(waveform, rise, top, tau, scaleFactor, threshold):
 	'''
 	This function emulates the DAQ filtering for the given input waveform and parameters.
@@ -608,7 +627,7 @@ def emulateDAQFilter(waves, rise, top, tau, triggerThreshold):
 			print('Install from: https://github.com/francof2a/fxpmath ')
 			return [], []
 
-@jit
+@numba.jit
 def extractTrapResults(filtered, rise, top, percentage, shift = 0, mean = 0):
 	"""
 	This function extracts the results from the trapezoidal filter. It does so with a percent threshold cross algorithm so it looks for a maximum, identifies the filter output information, and extracts timing and energy information from this.
@@ -1030,7 +1049,7 @@ def calcATWA(matrix, weight = None):
 		w = np.copy(weight)
 	return np.matmul(matrix, np.matmul(weight, matrix))
 
-@jit
+@numba.jit
 def __pseudoFitPSDAlongAxis(waves, maxLocs, fitMatrix, pseudoInverse, filtert0, filterLength, searchRange, t0Weight, numIdeal, psdInverses, psdWeight, returnResiduals):
 	shape = None
 	if numIdeal > 1: #if there are multiple
@@ -1283,7 +1302,7 @@ def pseudoInverseFit(waves, templates, baselines, filtert0 = None, searchRange =
 			return [bestParameters, t0s, minChis, None]
 		return [None, None, None, None]
 
-@jit
+@numba.jit
 def __pseudoFitSubLoopTrapFilter(waves, maxLocs, fitMatrix, pseudoInverse, filtert0, filterLength, 
 					 searchRange, t0Weight, numIdeal, trapFilter, rise, top, shift=0):
 	results = []
@@ -1478,7 +1497,7 @@ def pseudoInverseTrapFilter(waves, templates, baselines, rise, top, tau,
 								rise, top, filtert0=filtert0, searchRange = searchRange, 
 								t0Weight = t0Weight, batchsize = batchsize, dtype=np.float64, shift = shift)
 		return results.compute()
-@jit
+@numba.jit
 def doubleExp(x, amp, t0, decay1, decay2, offset):
 	"""
 	This function defines a double exponential function that is often used for fitting waveforms
@@ -1509,7 +1528,7 @@ def doubleExp(x, amp, t0, decay1, decay2, offset):
 	out[int(t0):] = offset + amp * (np.exp(-decayRegion/decay1)-np.exp(-decayRegion/decay2))
 	return out
 
-@jit
+@numba.jit
 def waveSigmoidFunc(x, amp, t0, decay1, decay2, offset, linear):
 	"""
 	This function defines a double exponential function that is often used for fitting waveforms
@@ -1596,7 +1615,7 @@ def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
 			temp = da.fft.rfft(shifted, axis=1)
 			temp = da.multiply(temp, smooth)
 			shifted = da.fft.irfft(temp)
-		@jit
+		@numba.jit
 		def findCrossPoints(wave):
 			maxval = np.max(wave)
 			maxloc = np.argmax(wave)
@@ -1667,7 +1686,7 @@ def fitFunction(xdata, ydata, function = None, bounds = None, p0 = None):
 	return popt, pcov
 
 
-@jit
+@numba.jit
 def expFit(x, amp, decay1, offset):
 	"""
 	This function defines a simple exponentially decaying function that is used for fitting the decay rate of waveforms
@@ -2063,7 +2082,7 @@ def antiCoincidenceCut(data, category, duration):
 	out[1:-1] = out[1:-1] | cut #or with that array
 	return out
 
-@jit
+@numba.jit
 def optimizedCorruptionCheck(timestamps, reqs, boards):
 	outputIndices = np.zeros(len(timestamps), dtype=np.bool_)
 	outputIndices[:] = True
