@@ -219,7 +219,7 @@ class waveformFile:
 			if self.getFileStartTime() is not None:
 				startTime = self.getFileStartTime()
 				#now shift all of the FPGA times by this
-				self.__headers['unix timestamp'] = self.__headers['timestamp'] + startTime[0] / (4E-9)
+				self.__headers['unix timestamp'] = self.__headers['timestamp'] + startTime / (4E-9)
 		else:
 			self.__headers = None
 			self.__waves = None
@@ -377,16 +377,15 @@ class waveformFile:
 	def getFileStartTime(self):
 		"""
 		This function returns the start time of the file as a unix timestamp in UTC
-		If multiple files, it returns all of them in a list
-		Some file formats don't have this information available. Those return a None in the list
+		If multiple files, it returns the first start time from the various files.
 		"""
 		if self.__startTime is not None and self.__hdf5:
 			return self.__startTime
 		else:
 			headers = self.fileHeaders()
 			if len(headers) != 0:
-				if 'unix timestamp' in headers[0]:
-					return headers[0]['unix timestamp']
+				if 'unix timestamp' in headers[0]: #check to make sure that value is in the header
+					return headers[0]['unix timestamp'] #this just returns the first element
 				else:
 					return None
 	def fileHeaders(self, fileNumber = None):
